@@ -5,14 +5,14 @@ module Temple
     class Tilt < ::Tilt::Template
       extend Mixins::Template
 
-      define_options :mime_type => 'text/html'
+      define_options mime_type: 'text/html'
 
       def self.default_mime_type
-        default_options[:mime_type]
+        options[:mime_type]
       end
 
       def self.default_mime_type=(mime_type)
-        default_options[:mime_type] = mime_type
+        options[:mime_type] = mime_type
       end
 
       # Prepare Temple template
@@ -21,10 +21,12 @@ module Temple
       #
       # @return [void]
       def prepare
-        # Overwrite option: No streaming support in Tilt
-        opts = {}.update(self.class.default_options).update(options).update(:file => eval_file, :streaming => false)
+        opts = {}.update(self.class.options).update(options).update(file: eval_file)
         opts.delete(:mime_type)
-        opts.delete(:outvar) # Sinatra gives us this invalid variable
+        if opts.include?(:outvar)
+          opts[:buffer] = opts.delete(:outvar)
+          opts[:save_buffer] = true
+        end
         @src = self.class.compile(data, opts)
       end
 
